@@ -14,19 +14,16 @@ from collections import UserList
 from numbers import Number
 from decimal import Decimal
 from fractions import Fraction
-
-dispatch_table_store = {}
+from typing import Any, Callable, Dict, Optional, Union
 
 
-class NonNumericTypeError(Exception):
-    pass
+# Type declarations
+IntOrFloat = Union[int, float]
+
+dispatch_table_store: Dict = {}
 
 
-class NonCallableError(Exception):
-    pass
-
-
-def types_lookup(type_name):
+def types_lookup(type_name: str) -> Optional[Any]:
     # helper function to get a type.
     # if type_name does not exist (because of the Python version), return None
     return getattr(types, type_name, None)
@@ -55,6 +52,11 @@ def _do(func, obj, digits, use_copy):
             return map(convert, obj_copy)
         return map(convert, obj)
 
+    def convert_filter(obj):
+        return filter(
+            bool, convert_map(obj)
+        )  # bool of map object is always True
+
     def convert_generator(obj):
         return map(convert, obj)
 
@@ -63,10 +65,12 @@ def _do(func, obj, digits, use_copy):
 
     def convert_dict(obj):
         if use_copy:
-            return {k: convert(v) for k, v in obj.items()}
+            return_obj = type(obj)()
+        else:
+            return_obj = obj
         for k, v in obj.items():
-            obj[k] = convert(v)
-        return obj
+            return_obj[k] = convert(v)
+        return return_obj
 
     def convert_array(obj):
         if use_copy:
@@ -106,7 +110,8 @@ def _do(func, obj, digits, use_copy):
         if isinstance(obj, map):
             return convert_map(obj)
         if hasattr(obj, "__dict__"):
-            # placed at the end as some of the above (derived) types might have a __dict__
+            # placed at the end as some of the above (derived) types
+            # might have a __dict__
             if use_copy:
                 obj_copy = copy.copy(obj)
                 for k, v in obj_copy.__dict__.items():
@@ -142,7 +147,7 @@ def _do(func, obj, digits, use_copy):
             array.array: convert_array,
             deque: convert_deque,
             map: convert_map,
-            filter: convert_map,
+            filter: convert_filter,
             range: convert_map,
             str: lambda obj: obj,
             types_lookup("NoneType"): lambda obj: obj,
@@ -168,7 +173,7 @@ def _do(func, obj, digits, use_copy):
     return convert(obj)
 
 
-def signif(x, digits):
+def signif(x: IntOrFloat, digits: int) -> IntOrFloat:
     """Round number to significant digits.
     Translated from Java algorithm available on
     <a href="http://stackoverflow.com/questions/202302">Stack Overflow</a>
@@ -193,20 +198,21 @@ def signif(x, digits):
     if x == 0:
         return 0
     if not isinstance(x, Number) or isinstance(x, complex):
-        raise NonNumericTypeError(
-            f"x must be a (non-complex) number, not '{type(x).__name__}'"
+        raise TypeError(
+            "x must be a (non-complex) number, "
+            f"not '{type(x).__name__}'"
         )
     d = math.ceil(math.log10(abs(x)))
     power = digits - d
     magnitude = math.pow(10, power)
     shifted = builtins.round(x * magnitude)
     if x >= math.pow(10, digits):
-        return round(shifted / magnitude)
+        return type(x)(round(shifted / magnitude))
     else:
-        return shifted / magnitude
+        return type(x)(shifted / magnitude)
 
 
-def round_object(obj, digits=None, use_copy=False):
+def round_object(obj: Any, digits: int = None, use_copy: bool = False) -> Any:
     """Round numbers in a Python object.
     Args:
         obj (any): any Python object
@@ -230,7 +236,7 @@ def round_object(obj, digits=None, use_copy=False):
     return _do(builtins.round, obj, [digits], use_copy)
 
 
-def ceil_object(obj, use_copy=False):
+def ceil_object(obj: Any, use_copy: bool = False) -> Any:
     """Round numbers in a Python object, using the ceiling algorithm.
     This means rounding to the closest greater integer.
     Args:
@@ -253,7 +259,7 @@ def ceil_object(obj, use_copy=False):
     return _do(math.ceil, obj, [], use_copy)
 
 
-def floor_object(obj, use_copy=False):
+def floor_object(obj: Any, use_copy: bool = False) -> Any:
     """Round numbers in a Python object, using the floor algorithm.
     This means rounding to the closest smaller integer.
     Args:
@@ -277,7 +283,7 @@ def floor_object(obj, use_copy=False):
     return _do(math.floor, obj, [], use_copy)
 
 
-def signif_object(obj, digits=3, use_copy=False):
+def signif_object(obj: Any, digits: int = 3, use_copy: bool = False):
     """Round numbers in a Python object to requested significant digits.
     Args:
         obj (any): any Python object
@@ -309,7 +315,11 @@ def signif_object(obj, digits=3, use_copy=False):
     return _do(signif, obj, [digits], use_copy)
 
 
-def map_object(map_function, obj, use_copy=False):
+def map_object(
+    map_function: Callable[[IntOrFloat], IntOrFloat],
+    obj: Any,
+    use_copy: bool = False,
+):
     """Maps recursively a Python object to a given function.
     Args:
         map_function: function that converts a number and returns a number
@@ -326,7 +336,10 @@ def map_object(map_function, obj, use_copy=False):
     >>> round_object(
     ...     map_object(
     ...         math.sin,
-    ...         {0:0, 90: math.radians(90), 180: math.radians(180), 270: math.radians(270)}),
+    ...         {0:0, 90: math.radians(90),
+    ...          180: math.radians(180),
+    ...          270: math.radians(270)}
+    ...     ),
     ...     3
     ... )
     {0: 0.0, 90: 1.0, 180: 0.0, 270: -1.0}
@@ -337,7 +350,47 @@ def map_object(map_function, obj, use_copy=False):
     {'number': 3.51, 'string': 'whatever', 'list': [11.1, 0.1]}
     """
     if not callable(map_function):
-        raise NonCallableError
+        raise TypeError(
+            "map_function must be a callable, "
+            f"not {type(map_function).__name__}"
+        )
+    return _do(map_function, obj, [], use_copy)
+
+
+def map_object_clean(
+    map_function: Callable[[IntOrFloat], IntOrFloat],
+    obj: Any,
+    use_copy: bool = False,
+):
+    """Maps recursively a Python object to a given function.
+    Args:
+        map_function: function that converts a number and returns a number
+        obj (any): any Python object
+        use_copy (bool, optional): use a deep copy or work with the original
+            object? Defaults to False, in which case mutable objects (a list
+            or a dict, for instance) will be affect inplace.
+    Returns:
+        any: the object with values mapped with the given map_function
+    >>> map_object(abs, -1)
+    1
+    >>> map_object(abs, [-2, -1, 0, 1, 2])
+    [2, 1, 0, 1, 2]
+    >>> round_object(
+    ...     map_object(
+    ...         math.sin,
+    ...         {0:0, 90: math.radians(90),
+    ...          180: math.radians(180),
+    ...          270: math.radians(270)}
+    ...     ),
+    ...     3
+    ... )
+    {0: 0.0, 90: 1.0, 180: 0.0, 270: -1.0}
+    >>> map_object(abs, "string")
+    'string'
+    >>> obj = {'number': 12.323, 'string': 'whatever', 'list': [122.45, .01]}
+    >>> map_object(lambda x: signif(x**.5, 3), obj)
+    {'number': 3.51, 'string': 'whatever', 'list': [11.1, 0.1]}
+    """
     return _do(map_function, obj, [], use_copy)
 
 
