@@ -258,13 +258,13 @@ def test_signif_ints():
 
 
 def test_signif_exception():
-    with pytest.raises(r.NonNumericTypeError):
+    with pytest.raises(TypeError, match="x must be a"):
         r.signif("string", 3)
 
-    with pytest.raises(r.NonNumericTypeError):
+    with pytest.raises(TypeError, match="x must be a"):
         r.signif([2.12], 3)
 
-    with pytest.raises(r.NonNumericTypeError):
+    with pytest.raises(TypeError, match="x must be a"):
         r.signif((1,), 3)
 
 
@@ -301,11 +301,11 @@ def test_map_object_basic():
 
 
 def test_map_object_exception():
-    with pytest.raises(r.NonCallableError):
+    with pytest.raises(TypeError, match='map_function'):
         r.map_object(2, 2)
-    with pytest.raises(r.NonCallableError):
+    with pytest.raises(TypeError, match='map_function'):
         r.map_object((lambda x: x)(2), 2)
-    with pytest.raises(r.NonCallableError):
+    with pytest.raises(TypeError, match='map_function'):
         r.map_object([], [2, 2])
 
 
@@ -496,6 +496,7 @@ def test_for_UserDict():
     d_rounded_copy = r.round_object(d, 2, True)
     assert d_rounded_copy == UserDict(dict(a=1.12, b=55.56))
     assert d == UserDict(dict(a=1.1212, b=55.559))
+    assert type(d_rounded_copy) == UserDict
 
     d_rounded_no_copy = r.round_object(d, 2, False)
     assert d_rounded_no_copy == UserDict(dict(a=1.12, b=55.56))
@@ -521,6 +522,7 @@ def test_for_UserDict():
     )
 
     assert d != d_rounded_copy
+    assert type(d_rounded_copy) == UserDict
 
     d_rounded_no_copy = r.round_object(d, 2, False)
     assert d_rounded_no_copy == d_rounded_copy
@@ -926,3 +928,29 @@ def test_no_copy_complex_object_with_map():
         3.0,
     ]
     assert len(list(obj["dict"]["map"])) == 0
+
+
+def test_int_from_signif():
+    assert isinstance(r.signif(12.2, 2), float)
+    assert isinstance(r.signif(1222222, 3), int)
+
+    x = [
+        {"x": 2, "y": 45.556},
+        (
+            175,
+            1222.3,
+        ),
+        2,
+    ]
+    assert isinstance(x[0]["x"], int)
+    assert isinstance(x[2], int)
+
+    x_rounded = r.signif_object(x)
+    assert isinstance(x_rounded[0]["x"], int)
+    assert isinstance(x_rounded[2], int)
+
+
+def test_int_return():
+    assert isinstance(r.round_object(10), int)
+    assert isinstance(r.ceil_object(10.234234), int)
+    assert isinstance(r.floor_object(10.234234), int)
